@@ -39,11 +39,13 @@ fn main() -> crossterm::Result<()> {
                 Font::Italic,
                 Font::BoldItalic,
                 Font::Sans,
-                Font::SansBold,
-                Font::SansItalic,
-                Font::SansBoldItalic,
+                Font::BoldSans,
+                Font::ItalicSans,
+                Font::BoldItalicSans,
                 Font::Script,
                 Font::BoldScript,
+                Font::Fraktur,
+                Font::BoldFraktur,
                 Font::Monospace,
                 Font::Blackboard,
             ];
